/*
 * Copyright (C) 2014 Yahoo Inc.
 */

/**
 * An object which controls the add contact button show/hide toggle behavior
 */
var addContactButtonController = {
	addressFieldTogglers: [],
	
	/**
	 * A method which creates instances of AddContactButton and holds onto the created object references
	 */
	create: function(focusableNode, inputFieldId, addContactButtonNode, uniqueTag) {
		if (!this.addressFieldTogglers[uniqueTag]) {
			this.addressFieldTogglers[uniqueTag] = new AddContactButton(focusableNode, inputFieldId, addContactButtonNode, uniqueTag);
		}
	}
};

/**
 * Instances of this class manage the toggling of the add contact button. An instance is created for each recipient field such as To/CC/BCC
 */
function AddContactButton(focusableNode, inputFieldId, addContactButtonNode, uniqueTag) {
	this.focusableNode = focusableNode;				// Usually the header node
	this.inputFieldId = inputFieldId;					// The id of the <input> field, focusing on which shows the corresponding add contact button
	this.addContactButtonNode = addContactButtonNode;	// The actual add contact button which is shown/hidden
	this.uniqueTag = uniqueTag;							// An unique tag associated with the current recipient field being managed

	this.focusableNode.addEventListener("focus", this.onFocus.bind(this), true);
	this.addContactButtonNode.addEventListener("click", this.onClick.bind(this), true);
};

/**
 * Traps focus events on the header.
 * - Checks if the input field is focused then shows the add contact button
 * - else Checks if the focus is not on the add contact button and hides it 
 */
AddContactButton.prototype.onFocus = function(event) {
	if (event.target.id === this.inputFieldId) {
		this.addContactButtonNode.classList.remove("hidden");
	} else if (event.target.id !== this.addContactButtonNode.id) {
		this.addContactButtonNode.classList.add("hidden");
	}
};

/**
 * The click handler for the add contact button
 */
AddContactButton.prototype.onClick = function() {
	yMailBridge.openContactPicker(this.uniqueTag);
};

