/*
 * Copyright (C) 2014 Yahoo Inc.
 */

/**
 * An object which controls the TextEditor tool bar which is shown/hidden via native code
 */
var nativeToolbarController = {
	headerNode: null,
	contentNode: null,
	lastBlurredElement: null,
	lastFocussedElement: null,
	
	/**
	 * A method which starts the nativeToolbarController
	 */
	init: function(headerNode, contentNode, yMailBridge) {
		this.headerNode = headerNode;
		this.contentNode = contentNode;
		this.lastBlurredElement = this.headerNode;
		
		this.headerNode.addEventListener("focus", this.headerFocusHandler.bind(this), true);
		this.contentNode.addEventListener("focus", this.contentFocusHandler.bind(this), true);
		
		this.headerNode.addEventListener("blur", this.headerBlurHandler.bind(this), true);
		this.contentNode.addEventListener("blur", this.contentBlurHandler.bind(this), true);
	},
	
	/**
	 * Handles focus events on the header portion of the compose view
	 */
	headerFocusHandler: function(event) {
		this.lastFocussedElement = this.headerNode;
		
		// Since the focus is on the header now, check if the last blurred element was the content node
		// if it is then we hide the toolbar
		if (this.lastBlurredElement === this.contentNode) {
			yMailBridge.toggleTextEditorToolbar(false);
		}
	},
	
	/**
	 * Handles focus events on the content portion of the compose view
	 */
	contentFocusHandler: function(event) {
		this.lastFocussedElement = this.contentNode;
		
		// Since the focus is on the content now, check if the last blurred element was the header node
		// if it is then we show the toolbar
		if (this.lastBlurredElement === this.headerNode) {
			yMailBridge.toggleTextEditorToolbar(true);
		}
		
		ccBccFromSummaryFieldController.collapseDetailIntoSummaryView();
	},
	
	/**
	 * Handles blur events on the header portion of the compose view
	 */
	headerBlurHandler: function(event) {
		this.lastBlurredElement = this.headerNode;
	},
	
	/**
	 * Handles blur events on the content portion of the compose view
	 */
	contentBlurHandler: function(event) {
		this.lastBlurredElement = this.contentNode;
	}
};